#
# spec file for package imb
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor openmpi5%{nil}

# Base package name
%define pname imb
%define PNAME IMB

%if "%flavor" == ""
%define package_name %{pname}
ExclusiveArch:  do_not_build
%endif

%if "%{flavor}" == "mvapich2"
%global mpi_flavor mvapich2
%define buildtarget "IMB-MPI1 IMB-EXT IMB-IO IMB-P2P"
%endif

%if "%{flavor}" == "mpich"
%global mpi_flavor mpich
%define buildtarget "IMB-MPI1 IMB-EXT IMB-IO IMB-P2P"
%endif

%if "%{flavor}" == "openmpi4"
%global mpi_flavor openmpi
%define mpi_vers 4
%define buildtarget "IMB-MPI1 IMB-EXT IMB-P2P"
%endif

%if "%{flavor}" == "openmpi5"
%global mpi_flavor openmpi
%define mpi_vers 5
%define buildtarget "IMB-MPI1 IMB-EXT IMB-P2P"
ExcludeArch:    %{ix86} %{arm}
%endif

%define p_bindir /usr/%_lib/mpi/gcc/%{flavor}/bin
%if "%{flavor}" == ""
%define package_name  %{pname}
%else
%define package_name  %{pname}-%{flavor}
%endif

Name:           %{package_name}
Version:        2021.8
Release:        3.1
Summary:        Intel MPI Benchmarks (IMB)
License:        BSD-3-Clause
Group:          Development/Tools/Other
URL:            https://software.intel.com/en-us/articles/intel-mpi-benchmarks
Source0:        https://github.com/intel/mpi-benchmarks/archive/IMB-v%{version}.tar.gz#/%{pname}_%{version}.tar.gz
Patch0:         imb-remove-Werror-flag.patch
Patch1:         src_c-Fix-multiple-size_t-issues-on-32b-systems.patch
BuildRequires:  %{flavor}-devel
BuildRequires:  gcc
BuildRequires:  gcc-c++
Obsoletes:      imb < %{version}

%description
The Intel MPI Benchmarks (IMB) perform a set of MPI performance
measurements for point-to-point and global communication operations for
a range of message sizes.

%prep
%autosetup -p1 -n mpi-benchmarks-IMB-v%{version}

%build

%define makeargs CC=/usr/%_lib/mpi/gcc/%{flavor}/bin/mpicc CXX=/usr/%_lib/mpi/gcc/%{flavor}/bin/mpic++
. /usr/%_lib/mpi/gcc/%{flavor}/bin/mpivars.sh
for target in $(echo %{?buildtarget}) ; do
echo "building $target"
make $target %{?makeargs} %{?_smp_mflags}
done
cd -

%install
%{__mkdir} -p %{buildroot}%{p_bindir}
cp IMB-*  %{buildroot}%{p_bindir}
mkdir -p %{buildroot}%{docdir}/%{name}
cat <<EOF > %{buildroot}%{docdir}/%{name}/README.SUSE
Product documentation is now available online only at: https://software.intel.com/en-us/imb-user-guide.
EOF
cd -

%files
%doc ReadMe_IMB.txt
%license license/license.txt license/use-of-trademark-license.txt
%{p_bindir}

%changelog
* Sat Mar 29 2025 Nicolas Morey <nicolas.morey@suse.com>
- Remove support for gnu-hpc build flavours.
* Mon Mar 24 2025 Nicolas Morey <nicolas.morey@suse.com>
- Disable gnu-hpc build flavours (bsc#1239982)
- Add openmpi5 build flavour
- openmpi5 is not available on 32b systems
- Fix mpi_ver for openmpi5
* Mon Aug 12 2024 Nicolas Morey <nicolas.morey@suse.com>
- Update to version 2021.8
  - Migration to icx,icpx compiler
  - IMB-MPI1: FP16/BF16 data_type support
  - Bug fixes
- Backport upstream patch imb-remove-Werror-flag.patch
  to fix compilation issues.
- Add src_c-Fix-multiple-size_t-issues-on-32b-systems.patch to fix
  compilation errors on 32b systems.
* Tue Jun 25 2024 Nicolas Morey <nicolas.morey@suse.com>
- Do not build hpc flavours on 32b systems.
* Wed Jan 17 2024 Egbert Eich <eich@suse.com>
- Update to version 2021.7
  * Change default value for mem_alloc_type to device
  * License update
  * Bug fixes
  * Currently not provided in SUSE:
    IMB-MPI1-GPU benchmark: Dynamically loading from LD_LIBRARY_PATH
    cuda or level zero library.
* Fri Oct 20 2023 Nicolas Morey <nicolas.morey@suse.com>
- Drop support for openmpi[123] (jsc#PED-7111)
- Prepare support for openmpi5
* Tue Oct 10 2023 Nicolas Morey <nicolas.morey@suse.com>
- Drop %%ver macro so that the Version tag can be parsed more easily
* Tue Jan  3 2023 Egbert Eich <eich@suse.com>
- Add build support for gcc11/12.
* Thu Sep 15 2022 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Update to 2021.3:
  - Change default value for mem_alloc_type to device
  - License update
  - Bug fixes.
* Fri Apr  9 2021 Christian Goll <cgoll@suse.com>
- Update to 2021.2:
  * New IMB-MPI1-GPU benchmarks (Technical Preview).
    The benchmarks implement the GPU version of the IMB-MPI1
  * Added -msg_pause option.
  * Changed default window_size 64 -> 256
  * Added -window_size option for IMB-MPI1
  * Bug fixes
* Fri Jan 22 2021 Egbert Eich <eich@suse.com>
- Fix openmpi HPC builds.
* Fri Jan 22 2021 Ana Guerrero Lopez <aguerrero@suse.com>
- Add support for gcc10.
- Add build support for openmpi4.
* Tue Oct 20 2020 Ana Guerrero Lopez <aguerrero@suse.com>
- Update to 2019.6
  * New IMB-P2P Stencil2D and Stencil3D benchmarks
  * Added Visual Studio projects for IMB-P2P
  * Bug fixes and code cleanup.
* Fri Nov 29 2019 Egbert Eich <eich@suse.com>
- Add support for gcc7.
- Add support for gcc8 and gcc9 (jsc#SLE-7766 & jsc#SLE-8604).
* Thu Nov 28 2019 Egbert Eich <eich@suse.com>
- Disable openmpi1 builds for SLE/Leap > 15.1.
- Enable openmpi3 builds for Leap and SLE > 15.1 (jsc#SLE-7773).
* Thu Oct 10 2019 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- openmpi has been renamed to openmpi1
* Tue Aug 27 2019 Ana Guerrero Lopez <aguerrero@suse.com>
- Update to 2019.3: (jsc#SLE-8508)
  * Added the warm_up option that enabled additional cycles before
    running benchmark(for all size.)
  * New IMB-P2P benchmarks.
  * Added the Reduce_local benchmark for IMB-MPI1.
  * Deleted the alignment option (-alignment).
  * Bug fixes and code cleanup.
- Add new target IMB-P2P.
- Update Source0 because upstream has renamed their tarballs.
* Thu Apr  4 2019 Christian Goll <cgoll@suse.com>
- Obsoletes now the imb package without flavor suffixes
* Wed Apr  3 2019 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Fix non-hpc flavor builds
* Wed Apr  3 2019 Christian Goll <cgoll@suse.com>
- added mpi library as suffix to name of the rpm (bsc#1131424)
* Sat Feb 16 2019 Egbert Eich <eich@suse.com>
- Fix whatis category in modules file (bsc#1125670).
* Mon Feb 11 2019 Egbert Eich <eich@suse.com>
- Properly create and tear down default version links when the
  HPC master packages are installed/uninstalled.
- Cosmetic changes to module file.
* Fri Jan 25 2019 eich@suse.com
- Disable openmpi1builds for SLE as well.
* Sun Jan 13 2019 eich@suse.com
- Disable openmpi3 builds on SLE.
* Wed Oct 31 2018 eich@suse.com
- Added non-HPC build flavors for MPI package testing.
- Updated to version 2019.1
* Fri Jan 26 2018 cgoll@suse.com
- added the documentation to the package
* Thu Dec  7 2017 cgoll@suse.com
- inital commit of version imb 4.1
